bgm_fit: Fit a Bayesian analysis of networks

View source: R/bgm_fit_class.R

bgm_fitR Documentation

Fit a Bayesian analysis of networks

Description

Fit a Bayesian analysis of networks

Usage

bgm_fit(fit, ...)

Arguments

fit

Object with a particular class that will dispatch to the respective package functions

...

Additional arguments to be passed onto the respective fitting functions


easybgm documentation built on Dec. 8, 2025, 5:11 p.m.