| edgeevidence | R Documentation |
The edge evidence plot colors edges according to their hypothesis testing results: blue for included, light blue for weakly included, gray for inconclusive, light yellow for weakly excluded, and yellow for excluded. This plot can be used to visualize the hypothesis testing results whether edge presence or absence. The edge evidence plot can aid researchers in deciding which edges provide robust inferential conclusions
plot_edgeevidence(
output,
evidence_thresh = 10,
split = FALSE,
show = "all",
...
)
output |
Output object from the easybgm function. Supports also objects from the bgm function of the |
evidence_thresh |
Bayes Factor which will be considered sufficient evidence for in-/exclusion, default is 10. Note that this parameter defines when edges provide sufficient evidence, thus when the edge color will turn saturated blue or yellow. All edges with a BF between 3 and the evidence threshold will receive a light saturated edge color. |
split |
if TRUE, plot is split in included and excluded edges. Note that by default separate plots are shown and appear after each other in the plot window. To show the plots side-by-side specify par(mfrow = c(1, 2)). |
show |
specifies which edges should be shown, indicated by "all", "included", "inconclusive", "excluded". |
... |
Additional arguments passed onto |
Returns a plot
library(easybgm)
library(bgms)
data <- na.omit(Wenchuan)
fit <- easybgm(data, type = "continuous",
iter = 100 # for demonstration only (> 5e4 recommended)
)
plot_edgeevidence(fit)
oldpar <- par(mfrow = c(1,1))
par(mfrow = c(1, 2))
plot_edgeevidence(fit, split = TRUE)
#' par(mfrow = c(1, 3))
plot_edgeevidence(fit, show = "included")
plot_edgeevidence(fit, show = "inconclusive")
plot_edgeevidence(fit, show = "excluded")
par(oldpar)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.